/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2015 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp15nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp15ni ;

DATA library.&dataset ;
INFILE datafile LRECL=2119;
INPUT
   ACCEPT  1-2              BOOKER2  3               BOOKER3  4            
   BOOKERCD  5-6            BUSCLAS  7-10            CANTPAY  11           
   CCULPSCO  12-13          CH2APP  14               CH8FINGD  15          
   CMSRVORD  16             COFI  17                 COMPLY  18            
   COMPLYPR  19             CRIMPURP  20             DETBFINE  21          
   DISPOSIT  22             EMPLOYNM  23             FCULPSCO  24-25       
   FRAUDTYP  26-27          FINSTDS  28              HISTORY  29           
   HSMISCND  30             INCORLOC  31             INCORPYR  32-35       
   INDICT  36               INPLEA1  37              INPLEA2  38           
   INPLEA3  39              INPLEA4  40              INPLEA5  41           
   INPLEA6  42              INPLEA7  43              INPLEA8  44           
   INPLEA9  45              INPLEA10  46             INPLEA11  47          
   INPLEA12  48             INNOPL1  49              INNOPL2  50           
   INNOPL3  51              INNOPL4  52              INNOPL5  53           
   INNOPL6  54              INNOPL7  55              INNOPL8  56           
   INNOPL9  57              INNOPL10  58             INNOPL11  59          
   INNOPL12  60             JANDC  61                NEWCNVTN  62          
   NOCOMP  63               NOCOUNTS  64-65          NOREAVAR  66          
   NOUSTAT  67              OBSTRUCT  68             OFFLVL  69-70         
   ORDERCE  71              ORGTYPE  72              OWNSTRCT  73-74       
   PLEA  75                 PRIMOFF  76-77           PRCIVIL  78           
   PRCRIME  79              PROBATN  80-81           PROBMON  82           
   PSR  83                  QUARTER  84              REAS1  85-88          
   REAS2  89-91             REAS3  92-94             REAS4  95             
   REASON4  96              REASONS  97              REMEDORD  98          
   SELFREP  99              SOURCES  100             TOLERNCE  101         
   TYPEOTHS  102-103        VICTNOTE  104            VIOLATE  105          
   AMENDYR  106-109         SENTYR  110-113          BASEFINE  114-122     
   COSTASSM  123-125        DISGORGE  126-133        FINOFFST  134         
   FORFEITR  135-142        GLFINMAX  143-152        GLFINMIN  153-162     
   STATMIN  163-166         STATMAX  167-175         RESTCAT  176          
   FINECAT  177             SUSFNCAT  178            LCAT1  179            
   LCAT2  180               LCATHI  181              LCATS1  182           
   LCATS2  183              LCATSHI  184             LCATR1  185           
   LCATR2  186              LCATRHI  187             LCATC1  188           
   LCATC2  189              LCATCHI  190             LCATU1  191           
   LCATU2  192              LCATUHI  193             CPIDN  194-200        
   BUSTEXT $ 201-254        OWNSTEXT $ 255-310       FINSTXT $ 311-386     
   PRMONTXT $ 387-455       TYPEOTTX $ 456-655       ORDERTXT $ 656-755    
   MINFINML  756-758        MAXFINML  759-761        ADJOFL1  762-763      
   ADJOFL2  764-765         ADJOFLHI  766-767        ADJ_B1  768-769       
   ADJ_B2  770-771          ADJ_BHI  772-773         ADJ_C1  774           
   ADJ_C2  775              ADJ_CHI  776             ADJ_D1  777           
   ADJ_D2  778              ADJ_DHI  779             ADJ_E1  780           
   ADJ_E2  781              ADJ_EHI  782             ADJ_F1  783           
   ADJ_F2  784              ADJ_FHI  785             ADJ_G1  786           
   ADJ_G2  787              ADJ_GHI  788             ADJ_H1  789           
   ADJ_H2  790              ADJ_HHI  791             ADJ_I1  792           
   ADJ_I2  793              ADJ_IHI  794             ADJ_J1  795           
   ADJ_J2  796              ADJ_JHI  797             ADJ_K1  798           
   ADJ_K2  799              ADJ_KHI  800             ADJ_L1  801           
   ADJ_L2  802              ADJ_LHI  803             ADJ_M1  804           
   ADJ_M2  805              ADJ_MHI  806             ADJ_N1  807           
   ADJ_N2  808              ADJ_NHI  809             ADJ_O1  810           
   ADJ_O2  811              ADJ_OHI  812             ADJ_P1  813           
   ADJ_P2  814              ADJ_PHI  815             ADJ_Q1  816           
   ADJ_Q2  817              ADJ_QHI  818             ADJ_R1  819           
   ADJ_R2  820              ADJ_RHI  821             ADJ_S1  822           
   ADJ_S2  823              ADJ_SHI  824             BASADJ1  825-826      
   BASADJ2  827             BASADJHI  828-829        BASE1  830-831        
   BASE2  832-833           BASEHI  834-835          BASLN1  836           
   BASLN2  837              BASLNHI  838             ADJOFR1  839-840      
   ADJOFR2  841             ADJOFRHI  842-843        ADJR_B1  844-845      
   ADJR_B2  846             ADJR_BHI  847-848        ADJR_C1  849          
   ADJR_C2  850             ADJR_CHI  851            ADJR_D1  852          
   ADJR_D2  853             ADJR_DHI  854            ADJR_E1  855          
   ADJR_E2  856             ADJR_EHI  857            ADJR_F1  858          
   ADJR_F2  859             ADJR_FHI  860            ADJR_G1  861          
   ADJR_G2  862             ADJR_GHI  863            ADJR_H1  864          
   ADJR_H2  865             ADJR_HHI  866            ADJR_I1  867          
   ADJR_I2  868             ADJR_IHI  869            ADJR_J1  870          
   ADJR_J2  871             ADJR_JHI  872            ADJR_K1  873          
   ADJR_K2  874             ADJR_KHI  875            ADJR_L1  876          
   ADJR_L2  877             ADJR_LHI  878            ADJR_M1  879          
   ADJR_M2  880             ADJR_MHI  881            ADJR_N1  882          
   ADJR_N2  883             ADJR_NHI  884            ADJR_O1  885          
   ADJR_O2  886             ADJR_OHI  887            ADJR_P1  888          
   ADJR_P2  889             ADJR_PHI  890            ADJR_Q1  891          
   ADJR_Q2  892             ADJR_QHI  893            ADJR_R1  894          
   ADJR_R2  895             ADJR_RHI  896            ADJR_S1  897          
   ADJR_S2  898             ADJR_SHI  899            BASADR1  900          
   BASADR2  901             BASADRHI  902            BASER1  903-904       
   BASER2  905              BASERHI  906-907         BASLNR1  908          
   BASLNR2  909             BASLNRHI  910            ADJOFS1  911-912      
   ADJOFS2  913-914         ADJOFSHI  915-916        ADJS_B1  917-918      
   ADJS_B2  919-920         ADJS_BHI  921-922        ADJS_C1  923          
   ADJS_C2  924             ADJS_CHI  925            ADJS_D1  926          
   ADJS_D2  927             ADJS_DHI  928            ADJS_E1  929          
   ADJS_E2  930             ADJS_EHI  931            ADJS_F1  932          
   ADJS_F2  933             ADJS_FHI  934            ADJS_G1  935          
   ADJS_G2  936             ADJS_GHI  937            ADJS_H1  938          
   ADJS_H2  939             ADJS_HHI  940            ADJS_I1  941          
   ADJS_I2  942             ADJS_IHI  943            ADJS_J1  944          
   ADJS_J2  945             ADJS_JHI  946            ADJS_K1  947          
   ADJS_K2  948             ADJS_KHI  949            ADJS_L1  950          
   ADJS_L2  951             ADJS_LHI  952            ADJS_M1  953          
   ADJS_M2  954             ADJS_MHI  955            ADJS_N1  956          
   ADJS_N2  957             ADJS_NHI  958            ADJS_O1  959          
   ADJS_O2  960             ADJS_OHI  961            ADJS_P1  962          
   ADJS_P2  963             ADJS_PHI  964            ADJS_Q1  965          
   ADJS_Q2  966             ADJS_QHI  967            ADJS_R1  968          
   ADJS_R2  969             ADJS_RHI  970            ADJS_S1  971          
   ADJS_S2  972             ADJS_SHI  973            BASADS1  974-975      
   BASADS2  976             BASADSHI  977-978        BASES1  979-980       
   BASES2  981-982          BASESHI  983-984         BASLNS1  985          
   BASLNS2  986             BASLNSHI  987            ADJOFC1  988-989      
   ADJOFC2  990             ADJOFCHI  991-992        ADJC_B1  993-994      
   ADJC_B2  995             ADJC_BHI  996-997        ADJC_C1  998          
   ADJC_C2  999             ADJC_CHI  1000           ADJC_D1  1001         
   ADJC_D2  1002            ADJC_DHI  1003           ADJC_E1  1004         
   ADJC_E2  1005            ADJC_EHI  1006           ADJC_F1  1007         
   ADJC_F2  1008            ADJC_FHI  1009           ADJC_G1  1010         
   ADJC_G2  1011            ADJC_GHI  1012           ADJC_H1  1013         
   ADJC_H2  1014            ADJC_HHI  1015           ADJC_I1  1016         
   ADJC_I2  1017            ADJC_IHI  1018           ADJC_J1  1019         
   ADJC_J2  1020            ADJC_JHI  1021           ADJC_K1  1022         
   ADJC_K2  1023            ADJC_KHI  1024           ADJC_L1  1025         
   ADJC_L2  1026            ADJC_LHI  1027           ADJC_M1  1028         
   ADJC_M2  1029            ADJC_MHI  1030           ADJC_N1  1031         
   ADJC_N2  1032            ADJC_NHI  1033           ADJC_O1  1034         
   ADJC_O2  1035            ADJC_OHI  1036           ADJC_P1  1037         
   ADJC_P2  1038            ADJC_PHI  1039           ADJC_Q1  1040         
   ADJC_Q2  1041            ADJC_QHI  1042           ADJC_R1  1043         
   ADJC_R2  1044            ADJC_RHI  1045           ADJC_S1  1046         
   ADJC_S2  1047            ADJC_SHI  1048           BASADC1  1049         
   BASADC2  1050            BASADCHI  1051           BASEC1  1052-1053     
   BASEC2  1054             BASECHI  1055-1056       BASLNC1  1057         
   BASLNC2  1058            BASLNCHI  1059           ADJOFU1  1060         
   ADJOFU2  1061            ADJOFUHI  1062           ADJU_B1  1063         
   ADJU_B2  1064            ADJU_BHI  1065           ADJU_C1  1066         
   ADJU_C2  1067            ADJU_CHI  1068           ADJU_D1  1069         
   ADJU_D2  1070            ADJU_DHI  1071           ADJU_E1  1072         
   ADJU_E2  1073            ADJU_EHI  1074           ADJU_F1  1075         
   ADJU_F2  1076            ADJU_FHI  1077           ADJU_G1  1078         
   ADJU_G2  1079            ADJU_GHI  1080           ADJU_H1  1081         
   ADJU_H2  1082            ADJU_HHI  1083           ADJU_I1  1084         
   ADJU_I2  1085            ADJU_IHI  1086           ADJU_J1  1087         
   ADJU_J2  1088            ADJU_JHI  1089           ADJU_K1  1090         
   ADJU_K2  1091            ADJU_KHI  1092           ADJU_L1  1093         
   ADJU_L2  1094            ADJU_LHI  1095           ADJU_M1  1096         
   ADJU_M2  1097            ADJU_MHI  1098           ADJU_N1  1099         
   ADJU_N2  1100            ADJU_NHI  1101           ADJU_O1  1102         
   ADJU_O2  1103            ADJU_OHI  1104           ADJU_P1  1105         
   ADJU_P2  1106            ADJU_PHI  1107           ADJU_Q1  1108         
   ADJU_Q2  1109            ADJU_QHI  1110           ADJU_R1  1111         
   ADJU_R2  1112            ADJU_RHI  1113           ADJU_S1  1114         
   ADJU_S2  1115            ADJU_SHI  1116           BASADU1  1117         
   BASADU2  1118            BASADUHI  1119           BASEU1  1120          
   BASEU2  1121             BASEUHI  1122            BASLNU1  1123         
   BASLNU2  1124            BASLNUHI  1125           ADJL_B1 $ 1126        
   ADJL_B2 $ 1127           ADJL_BHI $ 1128          ADJL_C1 $ 1129-1130   
   ADJL_C2 $ 1131           ADJL_CHI $ 1132-1133     ADJL_D1 $ 1134        
   ADJL_D2 $ 1135           ADJL_DHI $ 1136          ADJL_E1 $ 1137        
   ADJL_E2 $ 1138           ADJL_EHI $ 1139          ADJL_F1 $ 1140        
   ADJL_F2 $ 1141           ADJL_FHI $ 1142          ADJL_G1 $ 1143        
   ADJL_G2 $ 1144           ADJL_GHI $ 1145          ADJL_H1 $ 1146-1147   
   ADJL_H2 $ 1148           ADJL_HHI $ 1149-1150     ADJL_I1 $ 1151        
   ADJL_I2 $ 1152           ADJL_IHI $ 1153          ADJL_J1 $ 1154        
   ADJL_J2 $ 1155           ADJL_JHI $ 1156          ADJL_K1 $ 1157        
   ADJL_K2 $ 1158           ADJL_KHI $ 1159          ADJL_L1 $ 1160-1161   
   ADJL_L2 $ 1162           ADJL_LHI $ 1163-1164     ADJL_M1 $ 1165        
   ADJL_M2 $ 1166           ADJL_MHI $ 1167          ADJL_N1 $ 1168        
   ADJL_N2 $ 1169           ADJL_NHI $ 1170          ADJL_O1 $ 1171        
   ADJL_O2 $ 1172           ADJL_OHI $ 1173          ADJL_P1 $ 1174        
   ADJL_P2 $ 1175           ADJL_PHI $ 1176          ADJL_Q1 $ 1177        
   ADJL_Q2 $ 1178           ADJL_QHI $ 1179          ADJL_R1 $ 1180        
   ADJL_R2 $ 1181           ADJL_RHI $ 1182          ADJL_S1 $ 1183        
   ADJL_S2 $ 1184           ADJL_SHI $ 1185          BASEL1 $ 1186         
   BASEL2 $ 1187            BASELHI $ 1188           ADRL_B1 $ 1189        
   ADRL_B2 $ 1190           ADRL_BHI $ 1191          ADRL_C1 $ 1192        
   ADRL_C2 $ 1193           ADRL_CHI $ 1194          ADRL_D1 $ 1195        
   ADRL_D2 $ 1196           ADRL_DHI $ 1197          ADRL_E1 $ 1198        
   ADRL_E2 $ 1199           ADRL_EHI $ 1200          ADRL_F1 $ 1201        
   ADRL_F2 $ 1202           ADRL_FHI $ 1203          ADRL_G1 $ 1204        
   ADRL_G2 $ 1205           ADRL_GHI $ 1206          ADRL_H1 $ 1207        
   ADRL_H2 $ 1208           ADRL_HHI $ 1209          ADRL_I1 $ 1210        
   ADRL_I2 $ 1211           ADRL_IHI $ 1212          ADRL_J1 $ 1213        
   ADRL_J2 $ 1214           ADRL_JHI $ 1215          ADRL_K1 $ 1216        
   ADRL_K2 $ 1217           ADRL_KHI $ 1218          ADRL_L1 $ 1219        
   ADRL_L2 $ 1220           ADRL_LHI $ 1221          ADRL_M1 $ 1222        
   ADRL_M2 $ 1223           ADRL_MHI $ 1224          ADRL_N1 $ 1225        
   ADRL_N2 $ 1226           ADRL_NHI $ 1227          ADRL_O1 $ 1228        
   ADRL_O2 $ 1229           ADRL_OHI $ 1230          ADRL_P1 $ 1231        
   ADRL_P2 $ 1232           ADRL_PHI $ 1233          ADRL_Q1 $ 1234        
   ADRL_Q2 $ 1235           ADRL_QHI $ 1236          ADRL_R1 $ 1237        
   ADRL_R2 $ 1238           ADRL_RHI $ 1239          ADRL_S1 $ 1240        
   ADRL_S2 $ 1241           ADRL_SHI $ 1242          BASERL1 $ 1243        
   BASERL2 $ 1244           BASERLHI $ 1245          ADSL_B1 $ 1246        
   ADSL_B2 $ 1247           ADSL_BHI $ 1248          ADSL_C1 $ 1249-1250   
   ADSL_C2 $ 1251           ADSL_CHI $ 1252-1253     ADSL_D1 $ 1254        
   ADSL_D2 $ 1255           ADSL_DHI $ 1256          ADSL_E1 $ 1257        
   ADSL_E2 $ 1258           ADSL_EHI $ 1259          ADSL_F1 $ 1260        
   ADSL_F2 $ 1261           ADSL_FHI $ 1262          ADSL_G1 $ 1263        
   ADSL_G2 $ 1264           ADSL_GHI $ 1265          ADSL_H1 $ 1266-1267   
   ADSL_H2 $ 1268           ADSL_HHI $ 1269-1270     ADSL_I1 $ 1271        
   ADSL_I2 $ 1272           ADSL_IHI $ 1273          ADSL_J1 $ 1274        
   ADSL_J2 $ 1275           ADSL_JHI $ 1276          ADSL_K1 $ 1277        
   ADSL_K2 $ 1278           ADSL_KHI $ 1279          ADSL_L1 $ 1280-1281   
   ADSL_L2 $ 1282           ADSL_LHI $ 1283-1284     ADSL_M1 $ 1285        
   ADSL_M2 $ 1286           ADSL_MHI $ 1287          ADSL_N1 $ 1288        
   ADSL_N2 $ 1289           ADSL_NHI $ 1290          ADSL_O1 $ 1291        
   ADSL_O2 $ 1292           ADSL_OHI $ 1293          ADSL_P1 $ 1294        
   ADSL_P2 $ 1295           ADSL_PHI $ 1296          ADSL_Q1 $ 1297        
   ADSL_Q2 $ 1298           ADSL_QHI $ 1299          ADSL_R1 $ 1300        
   ADSL_R2 $ 1301           ADSL_RHI $ 1302          ADSL_S1 $ 1303        
   ADSL_S2 $ 1304           ADSL_SHI $ 1305          BASESL1 $ 1306        
   BASESL2 $ 1307           BASESLHI $ 1308          ADCL_B1 $ 1309        
   ADCL_B2 $ 1310           ADCL_BHI $ 1311          ADCL_C1 $ 1312        
   ADCL_C2 $ 1313           ADCL_CHI $ 1314          ADCL_D1 $ 1315        
   ADCL_D2 $ 1316           ADCL_DHI $ 1317          ADCL_E1 $ 1318        
   ADCL_E2 $ 1319           ADCL_EHI $ 1320          ADCL_F1 $ 1321        
   ADCL_F2 $ 1322           ADCL_FHI $ 1323          ADCL_G1 $ 1324        
   ADCL_G2 $ 1325           ADCL_GHI $ 1326          ADCL_H1 $ 1327        
   ADCL_H2 $ 1328           ADCL_HHI $ 1329          ADCL_I1 $ 1330        
   ADCL_I2 $ 1331           ADCL_IHI $ 1332          ADCL_J1 $ 1333        
   ADCL_J2 $ 1334           ADCL_JHI $ 1335          ADCL_K1 $ 1336        
   ADCL_K2 $ 1337           ADCL_KHI $ 1338          ADCL_L1 $ 1339        
   ADCL_L2 $ 1340           ADCL_LHI $ 1341          ADCL_M1 $ 1342        
   ADCL_M2 $ 1343           ADCL_MHI $ 1344          ADCL_N1 $ 1345        
   ADCL_N2 $ 1346           ADCL_NHI $ 1347          ADCL_O1 $ 1348        
   ADCL_O2 $ 1349           ADCL_OHI $ 1350          ADCL_P1 $ 1351        
   ADCL_P2 $ 1352           ADCL_PHI $ 1353          ADCL_Q1 $ 1354        
   ADCL_Q2 $ 1355           ADCL_QHI $ 1356          ADCL_R1 $ 1357        
   ADCL_R2 $ 1358           ADCL_RHI $ 1359          ADCL_S1 $ 1360        
   ADCL_S2 $ 1361           ADCL_SHI $ 1362          BASECL1 $ 1363        
   BASECL2 $ 1364           BASECLHI $ 1365          ADUL_B1 $ 1366        
   ADUL_B2 $ 1367           ADUL_BHI $ 1368          ADUL_C1 $ 1369        
   ADUL_C2 $ 1370           ADUL_CHI $ 1371          ADUL_D1 $ 1372        
   ADUL_D2 $ 1373           ADUL_DHI $ 1374          ADUL_E1 $ 1375        
   ADUL_E2 $ 1376           ADUL_EHI $ 1377          ADUL_F1 $ 1378        
   ADUL_F2 $ 1379           ADUL_FHI $ 1380          ADUL_G1 $ 1381        
   ADUL_G2 $ 1382           ADUL_GHI $ 1383          ADUL_H1 $ 1384        
   ADUL_H2 $ 1385           ADUL_HHI $ 1386          ADUL_I1 $ 1387        
   ADUL_I2 $ 1388           ADUL_IHI $ 1389          ADUL_J1 $ 1390        
   ADUL_J2 $ 1391           ADUL_JHI $ 1392          ADUL_K1 $ 1393        
   ADUL_K2 $ 1394           ADUL_KHI $ 1395          ADUL_L1 $ 1396        
   ADUL_L2 $ 1397           ADUL_LHI $ 1398          ADUL_M1 $ 1399        
   ADUL_M2 $ 1400           ADUL_MHI $ 1401          ADUL_N1 $ 1402        
   ADUL_N2 $ 1403           ADUL_NHI $ 1404          ADUL_O1 $ 1405        
   ADUL_O2 $ 1406           ADUL_OHI $ 1407          ADUL_P1 $ 1408        
   ADUL_P2 $ 1409           ADUL_PHI $ 1410          ADUL_Q1 $ 1411        
   ADUL_Q2 $ 1412           ADUL_QHI $ 1413          ADUL_R1 $ 1414        
   ADUL_R2 $ 1415           ADUL_RHI $ 1416          ADUL_S1 $ 1417        
   ADUL_S2 $ 1418           ADUL_SHI $ 1419          BASEUL1 $ 1420        
   BASEUL2 $ 1421           BASEULHI $ 1422          GDLINE1 $ 1423-1427   
   GDLINE2 $ 1428-1432      GDSTAT1 $ 1433-1437      GDSTAT2 $ 1438-1442   
   GDREF1 $ 1443-1447       GDREF2 $ 1448            GDCROS1 $ 1449-1453   
   GDCROS2 $ 1454           GDUNDR1 $ 1455           GDUNDR2 $ 1456        
   GDLINEHI $ 1457-1461     GDSTATHI $ 1462-1466     GDREFHI $ 1467-1471   
   GDCROSHI $ 1472-1476     GDUNDRHI $ 1477          STA1_1 $ 1478-1488    
   STA1_2 $ 1489-1502       STA1_3 $ 1503-1511       STA1_4 $ 1512-1518    
   STA1_5 $ 1519-1525       STA1_6 $ 1526-1533       STA1_7 $ 1534-1541    
   STA1_8 $ 1542-1549       STA1_9 $ 1550-1555       STA1_10 $ 1556-1561   
   STA1_11 $ 1562-1567      STA1_12 $ 1568-1573      STA1_13 $ 1574-1579   
   STA1_14 $ 1580-1585      STA2_1 $ 1586-1597       STA2_2 $ 1598-1611    
   STA2_3 $ 1612-1620       STA2_4 $ 1621-1627       STA2_5 $ 1628-1634    
   STA2_6 $ 1635-1641       STA2_7 $ 1642-1648       STA2_8 $ 1649-1655    
   STA2_9 $ 1656-1662       STA2_10 $ 1663-1669      STA2_11 $ 1670-1676   
   STA2_12 $ 1677           STA2_13 $ 1678-1680      STA2_14 $ 1681-1683   
   STA3_1 $ 1684-1694       STA3_2 $ 1695-1702       STA3_3 $ 1703-1710    
   STA3_4 $ 1711-1718       STA3_5 $ 1719-1724       STA3_6 $ 1725-1730    
   STA3_7 $ 1731-1736       STA3_8 $ 1737-1742       STA3_9 $ 1743-1748    
   STA3_10 $ 1749-1754      STA3_11 $ 1755-1760      STA3_12 $ 1761        
   STA3_13 $ 1762           STA3_14 $ 1763           NWSTAT1 $ 1764-1774   
   NWSTAT2 $ 1775-1788      NWSTAT3 $ 1789-1800      NWSTAT4 $ 1801-1814   
   NWSTAT5 $ 1815-1825      NWSTAT6 $ 1826-1834      NWSTAT7 $ 1835-1837   
   SMAX1  1838-1846         SMAX2  1847-1854         SMAX3  1855-1862      
   SMAX4  1863-1870         SMAX5  1871-1876         SMAX6  1877-1882      
   SMAX7  1883-1888         SMAX8  1889-1894         SMAX9  1895-1900      
   SMAX10  1901-1906        SMAX11  1907-1912        SMAX12  1913-1918     
   SMAX13  1919-1924        SMAX14  1925-1930        SMIN1  1931-1934      
   SMIN2  1935              SMIN3  1936              SMIN4  1937           
   SMIN5  1938              SMIN6  1939              SMIN7  1940           
   SMIN8  1941              SMIN9  1942              SMIN10  1943          
   SMIN11  1944             SMIN12  1945             SMIN13  1946          
   SMIN14  1947             RETEXT1 $ 1948-1970      RETEXT2 $ 1971-2117   
   RETEXT3 $ 2118           RETEXT4 $ 2119         ;                       

LENGTH
   ACCEPT 3                 BOOKER2 3                BOOKER3 3             
   BOOKERCD 3               BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 4                  REAS4 3               
   REASON4 3                REASONS 3                REMEDORD 3            
   SELFREP 3                SOURCES 3                TOLERNCE 3            
   TYPEOTHS 3               VICTNOTE 3               VIOLATE 3             
   AMENDYR 4                SENTYR 4                 BASEFINE 6            
   COSTASSM 4               DISGORGE 6               FINOFFST 3            
   FORFEITR 6               GLFINMIN 6               STATMIN 4             
   STATMAX 6                RESTCAT 3                FINECAT 3             
   SUSFNCAT 3               LCAT1 3                  LCAT2 3               
   LCATHI 3                 LCATS1 3                 LCATS2 3              
   LCATSHI 3                LCATR1 3                 LCATR2 3              
   LCATRHI 3                LCATC1 3                 LCATC2 3              
   LCATCHI 3                LCATU1 3                 LCATU2 3              
   LCATUHI 3                CPIDN 6                  ADJOFL1 3             
   ADJOFL2 3                ADJOFLHI 3               ADJ_B1 3              
   ADJ_B2 3                 ADJ_BHI 3                ADJ_C1 3              
   ADJ_C2 3                 ADJ_CHI 3                ADJ_D1 3              
   ADJ_D2 3                 ADJ_DHI 3                ADJ_E1 3              
   ADJ_E2 3                 ADJ_EHI 3                ADJ_F1 3              
   ADJ_F2 3                 ADJ_FHI 3                ADJ_G1 3              
   ADJ_G2 3                 ADJ_GHI 3                ADJ_H1 3              
   ADJ_H2 3                 ADJ_HHI 3                ADJ_I1 3              
   ADJ_I2 3                 ADJ_IHI 3                ADJ_J1 3              
   ADJ_J2 3                 ADJ_JHI 3                ADJ_K1 3              
   ADJ_K2 3                 ADJ_KHI 3                ADJ_L1 3              
   ADJ_L2 3                 ADJ_LHI 3                ADJ_M1 3              
   ADJ_M2 3                 ADJ_MHI 3                ADJ_N1 3              
   ADJ_N2 3                 ADJ_NHI 3                ADJ_O1 3              
   ADJ_O2 3                 ADJ_OHI 3                ADJ_P1 3              
   ADJ_P2 3                 ADJ_PHI 3                ADJ_Q1 3              
   ADJ_Q2 3                 ADJ_QHI 3                ADJ_R1 3              
   ADJ_R2 3                 ADJ_RHI 3                ADJ_S1 3              
   ADJ_S2 3                 ADJ_SHI 3                BASADJ1 3             
   BASADJ2 3                BASADJHI 3               BASE1 3               
   BASE2 3                  BASEHI 3                 BASLN1 3              
   BASLN2 3                 BASLNHI 3                ADJOFR1 3             
   ADJOFR2 3                ADJOFRHI 3               ADJR_B1 3             
   ADJR_B2 3                ADJR_BHI 3               ADJR_C1 3             
   ADJR_C2 3                ADJR_CHI 3               ADJR_D1 3             
   ADJR_D2 3                ADJR_DHI 3               ADJR_E1 3             
   ADJR_E2 3                ADJR_EHI 3               ADJR_F1 3             
   ADJR_F2 3                ADJR_FHI 3               ADJR_G1 3             
   ADJR_G2 3                ADJR_GHI 3               ADJR_H1 3             
   ADJR_H2 3                ADJR_HHI 3               ADJR_I1 3             
   ADJR_I2 3                ADJR_IHI 3               ADJR_J1 3             
   ADJR_J2 3                ADJR_JHI 3               ADJR_K1 3             
   ADJR_K2 3                ADJR_KHI 3               ADJR_L1 3             
   ADJR_L2 3                ADJR_LHI 3               ADJR_M1 3             
   ADJR_M2 3                ADJR_MHI 3               ADJR_N1 3             
   ADJR_N2 3                ADJR_NHI 3               ADJR_O1 3             
   ADJR_O2 3                ADJR_OHI 3               ADJR_P1 3             
   ADJR_P2 3                ADJR_PHI 3               ADJR_Q1 3             
   ADJR_Q2 3                ADJR_QHI 3               ADJR_R1 3             
   ADJR_R2 3                ADJR_RHI 3               ADJR_S1 3             
   ADJR_S2 3                ADJR_SHI 3               BASADR1 3             
   BASADR2 3                BASADRHI 3               BASER1 3              
   BASER2 3                 BASERHI 3                BASLNR1 3             
   BASLNR2 3                BASLNRHI 3               ADJOFS1 3             
   ADJOFS2 3                ADJOFSHI 3               ADJS_B1 3             
   ADJS_B2 3                ADJS_BHI 3               ADJS_C1 3             
   ADJS_C2 3                ADJS_CHI 3               ADJS_D1 3             
   ADJS_D2 3                ADJS_DHI 3               ADJS_E1 3             
   ADJS_E2 3                ADJS_EHI 3               ADJS_F1 3             
   ADJS_F2 3                ADJS_FHI 3               ADJS_G1 3             
   ADJS_G2 3                ADJS_GHI 3               ADJS_H1 3             
   ADJS_H2 3                ADJS_HHI 3               ADJS_I1 3             
   ADJS_I2 3                ADJS_IHI 3               ADJS_J1 3             
   ADJS_J2 3                ADJS_JHI 3               ADJS_K1 3             
   ADJS_K2 3                ADJS_KHI 3               ADJS_L1 3             
   ADJS_L2 3                ADJS_LHI 3               ADJS_M1 3             
   ADJS_M2 3                ADJS_MHI 3               ADJS_N1 3             
   ADJS_N2 3                ADJS_NHI 3               ADJS_O1 3             
   ADJS_O2 3                ADJS_OHI 3               ADJS_P1 3             
   ADJS_P2 3                ADJS_PHI 3               ADJS_Q1 3             
   ADJS_Q2 3                ADJS_QHI 3               ADJS_R1 3             
   ADJS_R2 3                ADJS_RHI 3               ADJS_S1 3             
   ADJS_S2 3                ADJS_SHI 3               BASADS1 3             
   BASADS2 3                BASADSHI 3               BASES1 3              
   BASES2 3                 BASESHI 3                BASLNS1 3             
   BASLNS2 3                BASLNSHI 3               ADJOFC1 3             
   ADJOFC2 3                ADJOFCHI 3               ADJC_B1 3             
   ADJC_B2 3                ADJC_BHI 3               ADJC_C1 3             
   ADJC_C2 3                ADJC_CHI 3               ADJC_D1 3             
   ADJC_D2 3                ADJC_DHI 3               ADJC_E1 3             
   ADJC_E2 3                ADJC_EHI 3               ADJC_F1 3             
   ADJC_F2 3                ADJC_FHI 3               ADJC_G1 3             
   ADJC_G2 3                ADJC_GHI 3               ADJC_H1 3             
   ADJC_H2 3                ADJC_HHI 3               ADJC_I1 3             
   ADJC_I2 3                ADJC_IHI 3               ADJC_J1 3             
   ADJC_J2 3                ADJC_JHI 3               ADJC_K1 3             
   ADJC_K2 3                ADJC_KHI 3               ADJC_L1 3             
   ADJC_L2 3                ADJC_LHI 3               ADJC_M1 3             
   ADJC_M2 3                ADJC_MHI 3               ADJC_N1 3             
   ADJC_N2 3                ADJC_NHI 3               ADJC_O1 3             
   ADJC_O2 3                ADJC_OHI 3               ADJC_P1 3             
   ADJC_P2 3                ADJC_PHI 3               ADJC_Q1 3             
   ADJC_Q2 3                ADJC_QHI 3               ADJC_R1 3             
   ADJC_R2 3                ADJC_RHI 3               ADJC_S1 3             
   ADJC_S2 3                ADJC_SHI 3               BASADC1 3             
   BASADC2 3                BASADCHI 3               BASEC1 3              
   BASEC2 3                 BASECHI 3                BASLNC1 3             
   BASLNC2 3                BASLNCHI 3               ADJOFU1 3             
   ADJOFU2 3                ADJOFUHI 3               ADJU_B1 3             
   ADJU_B2 3                ADJU_BHI 3               ADJU_C1 3             
   ADJU_C2 3                ADJU_CHI 3               ADJU_D1 3             
   ADJU_D2 3                ADJU_DHI 3               ADJU_E1 3             
   ADJU_E2 3                ADJU_EHI 3               ADJU_F1 3             
   ADJU_F2 3                ADJU_FHI 3               ADJU_G1 3             
   ADJU_G2 3                ADJU_GHI 3               ADJU_H1 3             
   ADJU_H2 3                ADJU_HHI 3               ADJU_I1 3             
   ADJU_I2 3                ADJU_IHI 3               ADJU_J1 3             
   ADJU_J2 3                ADJU_JHI 3               ADJU_K1 3             
   ADJU_K2 3                ADJU_KHI 3               ADJU_L1 3             
   ADJU_L2 3                ADJU_LHI 3               ADJU_M1 3             
   ADJU_M2 3                ADJU_MHI 3               ADJU_N1 3             
   ADJU_N2 3                ADJU_NHI 3               ADJU_O1 3             
   ADJU_O2 3                ADJU_OHI 3               ADJU_P1 3             
   ADJU_P2 3                ADJU_PHI 3               ADJU_Q1 3             
   ADJU_Q2 3                ADJU_QHI 3               ADJU_R1 3             
   ADJU_R2 3                ADJU_RHI 3               ADJU_S1 3             
   ADJU_S2 3                ADJU_SHI 3               BASADU1 3             
   BASADU2 3                BASADUHI 3               BASEU1 3              
   BASEU2 3                 BASEUHI 3                BASLNU1 3             
   BASLNU2 3                BASLNUHI 3               SMAX1 6               
   SMAX2 6                  SMAX3 6                  SMAX4 6               
   SMAX5 6                  SMAX6 6                  SMAX7 6               
   SMAX8 6                  SMAX9 6                  SMAX10 6              
   SMAX11 6                 SMAX12 6                 SMAX13 6              
   SMAX14 6                 SMIN1 4                  SMIN2 3               
   SMIN3 3                  SMIN4 3                  SMIN5 3               
   SMIN6 3                  SMIN7 3                  SMIN8 3               
   SMIN9 3                  SMIN10 3                 SMIN11 3              
   SMIN12 3                 SMIN13 3                 SMIN14 3 ;

          

RUN ;
